# load-m3u8
[![License](https://img.shields.io/badge/license-Apache%202-4EB1BA.svg)](https://www.apache.org/licenses/LICENSE-2.0.html)

## Import
```
from load_m3u8.resolve import Load_M3U8

Load_M3U8("http://www.youtube.com/test.m3u8").run()
```

## Usage
```
pip --no-cache-dir install load-m3u8

load-m3u8 "http://www.youtube.com/test1.m3u8" "http://www.youtube.com/test2.m3u8"
`
